==> eam-wshub-proxyclient-11.4-4-sources.jar: net/datastream/schemas/mp_fields/RESOURCEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour RESOURCEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="RESOURCEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RESOURCECODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RESOURCEDESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RESOURCEID_Type", propOrder = {
    "resourcecode",
    "resourcedescription"
})
public class RESOURCEID_Type {

    @XmlElement(name = "RESOURCECODE", required = true)
    protected String resourcecode;
    @XmlElement(name = "RESOURCEDESCRIPTION")
    protected String resourcedescription;

    /**
     * Obtient la valeur de la propriété resourcecode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRESOURCECODE() {
        return resourcecode;
    }

    /**
     * Définit la valeur de la propriété resourcecode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRESOURCECODE(String value) {
        this.resourcecode = value;
    }

    /**
     * Obtient la valeur de la propriété resourcedescription.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRESOURCEDESCRIPTION() {
        return resourcedescription;
    }

    /**
     * Définit la valeur de la propriété resourcedescription.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRESOURCEDESCRIPTION(String value) {
        this.resourcedescription = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/RESOURCEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for RESOURCEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="RESOURCEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RESOURCECODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RESOURCEDESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RESOURCEID_Type", propOrder = {
    "resourcecode",
    "resourcedescription"
})
public class RESOURCEID_Type {

    @XmlElement(name = "RESOURCECODE", required = true)
    protected String resourcecode;
    @XmlElement(name = "RESOURCEDESCRIPTION")
    protected String resourcedescription;

    /**
     * Gets the value of the resourcecode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRESOURCECODE() {
        return resourcecode;
    }

    /**
     * Sets the value of the resourcecode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRESOURCECODE(String value) {
        this.resourcecode = value;
    }

    /**
     * Gets the value of the resourcedescription property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRESOURCEDESCRIPTION() {
        return resourcedescription;
    }

    /**
     * Sets the value of the resourcedescription property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRESOURCEDESCRIPTION(String value) {
        this.resourcedescription = value;
    }

}
